@@ -6,12 +6,16 @@ import string
 from string import punctuation
 from typing import Any, Dict, List, Optional, Set
 
+from hdx.utilities.typehint import ListTuple
+
 logger = logging.getLogger(__name__)
 
 PUNCTUATION_MINUS_BRACKETS = r"""!"#$%&'*+,-./:;<=>?@\^_`|~"""
 
 
-def remove_end_characters(string: str, characters_to_remove: str = punctuation) -> str:
+def remove_end_characters(
+    string: str, characters_to_remove: str = punctuation
+) -> str:
     """Remove any characters at end of string that are in characters_to_remove
 
     Args:
@@ -100,7 +104,9 @@ def multiple_replace(string: str, replacements: Dict[str, str]) -> str:
     if not replacements:
         return string
     pattern = re.compile(
-        "|".join([re.escape(k) for k in sorted(replacements, key=len, reverse=True)]),
+        "|".join(
+            [re.escape(k) for k in sorted(replacements, key=len, reverse=True)]
+        ),
         flags=re.DOTALL,
     )
     return pattern.sub(lambda x: replacements[x.group(0)], string)
@@ -116,11 +122,17 @@ def get_words_in_sentence(sentence: str) -> List[str]:
         List[str]: List of words in sentence
 
     """
-    return re.sub("[" + punctuation.replace("'", "") + "]", " ", sentence).split()
+    return re.sub(
+        "[" + punctuation.replace("'", "") + "]", " ", sentence
+    ).split()
 
 
 def get_matching_text_in_strs(
-    a: str, b: str, match_min_size: int = 30, ignore: str = "", end_characters: str = ""
+    a: str,
+    b: str,
+    match_min_size: int = 30,
+    ignore: str = "",
+    end_characters: str = "",
 ) -> List[str]:
     """Returns a list of matching blocks of text in a and b
 
@@ -275,7 +287,9 @@ def get_matching_then_nonmatching_text(
     return a
 
 
-def number_format(val: Any, format: str = "%.4f", trailing_zeros: bool = True) -> str:
+def number_format(
+    val: Any, format: str = "%.4f", trailing_zeros: bool = True
+) -> str:
     """Format float-castable input as string
 
     Args:
@@ -400,3 +414,30 @@ def get_numeric_if_possible(value: Any) -> Any:
                         val = val.replace(",", ".")
                     return float(val) / denominator
     return value
+
+
+def earliest_index(
+    string_to_search: str, strings_to_try: ListTuple[str]
+) -> Optional[int]:
+    """Search a string for each of a list of strings and return the earliest index.
+
+    Args:
+        string_to_search (str): String to search
+        strings_to_try (ListTuple[str]): Strings to try
+
+    Returns:
+        Optional[int]: Earliest index of the strings to try in string to search or None
+    """
+    after_string = len(string_to_search) + 1
+    indices = list()
+    for string_to_try in strings_to_try:
+        try:
+            index = string_to_search.index(string_to_try)
+            indices.append(index)
+        except ValueError:
+            indices.append(after_string)
+    earliest_index = sorted(indices)[0]
+    if earliest_index == after_string:
+        return None
+    else:
+        return earliest_index
